-- ----------------------------
-- 2024-04-08
-- ----------------------------
-- ----------------------------
-- 排号汇总表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_ph_queue`;
CREATE TABLE mortals_xhx_ph_queue(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `ordernumber` varchar(64) NOT NULL     COMMENT '预约编号，为空现场取号',
    `style` char(8) NOT NULL   DEFAULT '未叫号'  COMMENT '叫号状态 (未叫号,叫号中,完成)',
    `business` varchar(128) NOT NULL     COMMENT '业务名',
    `window_name` varchar(128) NOT NULL     COMMENT '窗口名',
    `window_fromnum` varchar(128) NOT NULL     COMMENT '窗口编号',
    `flownum` varchar(64) NOT NULL     COMMENT '流水编号,当天的第xxx号',
    `formernum` varchar(32) NOT NULL     COMMENT '呼叫转移号',
    `people_idcard` varchar(64) NOT NULL     COMMENT '身份证号',
    `people_name` varchar(64) NOT NULL     COMMENT '姓名',
    `people_sex` char(6) NOT NULL     COMMENT '性别',
    `people_phone` varchar(20) NOT NULL     COMMENT '手机号',
    `workman_name` varchar(32) NOT NULL     COMMENT '工作人员姓名',
    `workman_number` varchar(20) NOT NULL     COMMENT '工作人员工号',
    `taketime` datetime      COMMENT '取号时间',
    `calltime` datetime      COMMENT '叫号时间',
    `endtime` datetime      COMMENT '结束时间',
    `wait_time` int(9) NOT NULL   DEFAULT '0'  COMMENT '等待时间,单位s',
    `handle_time` int(9) NOT NULL   DEFAULT '0'  COMMENT '办理时间,单位s',
    `device_name` varchar(128) NOT NULL     COMMENT '取号设备名',
    `call_name` varchar(128) NOT NULL     COMMENT '呼叫设备',
    `matter_name` varchar(256) NOT NULL     COMMENT '事项名',
    `queueid` varchar(128) NOT NULL     COMMENT '排号队列ID',
    `wy_signin` varchar(16) NOT NULL   DEFAULT '现场取号'  COMMENT '取号方式 (现场取号,微信取号)',
    `section_name` varchar(128) NOT NULL     COMMENT '部门名称',
    `hall_name` varchar(128) NOT NULL     COMMENT '大厅名称',
    `device_type` varchar(32) NOT NULL   DEFAULT '排号机'  COMMENT '取号设备类型',
    `site_id` bigint(20) NOT NULL   DEFAULT '0'  COMMENT '站点Id',
    `site_code` varchar(128) NOT NULL     COMMENT '站点编码',
    `site_name` varchar(128)      COMMENT '站点名称',
    `ext_num` varchar(128) NOT NULL     COMMENT '扩展编号',
    `create_user_id` bigint(20)      COMMENT '创建用户',
    `create_time` datetime NOT NULL     COMMENT '创建时间',
    `update_time` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
,KEY `style` (`style`) USING BTREE
,KEY `business` (`business`) USING BTREE
,KEY `window_fromnum` (`window_fromnum`) USING BTREE
,KEY `people_idcard` (`people_idcard`) USING BTREE
,KEY `people_phone` (`people_phone`) USING BTREE
,KEY `workman_number` (`workman_number`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='排号汇总';





-- ----------------------------
-- 评价汇总统计表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_pj_evaluate`;
CREATE TABLE mortals_xhx_pj_evaluate(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `people_idcard` varchar(64) NOT NULL     COMMENT '评价人身份证号',
    `people_name` varchar(64) NOT NULL     COMMENT '评价人姓名',
    `people_sex` char(6) NOT NULL     COMMENT '评价人性别',
    `people_phone` varchar(20) NOT NULL     COMMENT '评价人手机号',
    `pj_option` varchar(32) NOT NULL     COMMENT '评价选项(非常满意,满意,基本满意,不满意,非常不满意)',
    `content_tag` varchar(255) NOT NULL     COMMENT '评价标签',
    `pic_url` varchar(128) NOT NULL     COMMENT '评价人图片地址',
    `section_name` varchar(128) NOT NULL     COMMENT '部门',
    `hall_name` varchar(128) NOT NULL     COMMENT '大厅',
    `pj_source` varchar(20) NOT NULL     COMMENT '评价来源 (安卓,导视机,微信)',
    `opinion` varchar(512)      COMMENT '手输意见',
    `window_name` varchar(128) NOT NULL     COMMENT '窗口名',
    `window_fromnum` varchar(128) NOT NULL     COMMENT '窗口编号',
    `flounum` varchar(20)      COMMENT '排号编号',
    `pjxt` varchar(32)    DEFAULT '窗口评价'  COMMENT '窗口评价(自助服务终端,背靠背评价,微官网)',
    `workman_name` varchar(32) NOT NULL     COMMENT '工作人员姓名',
    `workman_number` varchar(20) NOT NULL     COMMENT '工作人员工号',
    `devicenum` varchar(64)      COMMENT '评价器mac',
    `evaluatestatus` varchar(32)    DEFAULT '等待评价'  COMMENT '评价状态(等待评价,完成,截图有误,用户截图签名超时,用户评价超时,收到图片等待签名',
    `evaluatetype` char(8)    DEFAULT '截图'  COMMENT '截图还是评价 (截图,评价)',
    `photobefor` varchar(256) NOT NULL     COMMENT '截图地址',
    `photoautograph` varchar(256)      COMMENT '签字图片',
    `picture` varchar(256) NOT NULL     COMMENT '抓拍评价人照片',
    `process` varchar(256) NOT NULL     COMMENT '音频视频地址',
    `eyevaluate` varchar(16)    DEFAULT '未标记'  COMMENT '评价标记（未标记,标记非恶意差评,标记恶意差评)',
    `pj_type` varchar(16) NOT NULL   DEFAULT '窗口评价'  COMMENT '评价指向 (窗口评价,部门评价,排号评价)',
    `pj_time` datetime      COMMENT '评价时间',
    `site_id` bigint(20)    DEFAULT '0'  COMMENT '站点Id',
    `site_code` varchar(128)      COMMENT '站点编码',
    `site_name` varchar(128)      COMMENT '站点名称',
    `ext_num` varchar(128)      COMMENT '扩展编号',
    `create_user_id` bigint(20)      COMMENT '创建用户',
    `create_time` datetime NOT NULL     COMMENT '创建时间',
    `update_time` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
,KEY `people_idcard` (`people_idcard`) USING BTREE
,KEY `people_phone` (`people_phone`) USING BTREE
,KEY `pj_option` (`pj_option`) USING BTREE
,KEY `pj_source` (`pj_source`) USING BTREE
,KEY `site_id` (`site_id`) USING BTREE
,KEY `site_code` (`site_code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='评价汇总';
DROP TABLE IF EXISTS `mortals_xhx_pj_evaluate_stat`;


-- ----------------------------
-- 区域接入表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_access`;
CREATE TABLE mortals_xhx_access(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `area_id` varchar(64) NOT NULL   DEFAULT ''   COMMENT '区域Id',
    `area_name` varchar(64)  NOT NULL   DEFAULT ''    COMMENT '区域名称',
    `area_code` varchar(64)  NOT NULL   DEFAULT ''    COMMENT '区域编码',
    `site_id` bigint(20)      COMMENT '站点Id',
    `site_code` varchar(128) NOT NULL   DEFAULT ''     COMMENT '站点编码',
    `site_name` varchar(128) NOT NULL   DEFAULT ''     COMMENT '站点名称',
    `big_path` varchar(128) NOT NULL   DEFAULT ''    COMMENT '背景图片地址',
    `icon` varchar(128)  NOT NULL   DEFAULT ''   COMMENT '图标',
    `tag` varchar(255)  NOT NULL   DEFAULT ''    COMMENT '标签',
    `latitude` varchar(64)  NOT NULL   DEFAULT ''    COMMENT '维度',
    `longitude` varchar(64)      COMMENT '经度',
    `access_time` datetime      COMMENT '接入开通时间',
    `type` varchar(16) NOT NULL   DEFAULT '类型'  COMMENT '接入类型 (area.区域,site.站点)',
    `sort` int(4)    DEFAULT '0'  COMMENT '排序',
    `content` varchar(1024) NOT NULL   DEFAULT ''     COMMENT '描述内容',
    `remark` varchar(256) NOT NULL   DEFAULT ''     COMMENT '备注',
    `create_user_id` bigint(20)      COMMENT '创建用户',
    `create_time` datetime      COMMENT '创建时间',
    `update_time` datetime      COMMENT '更新时间',
    PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='区域接入';

-- ----------------------------
-- 区域接入系统表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_access_system`;
CREATE TABLE mortals_xhx_access_system(
      `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
      `accessId` bigint(20)      COMMENT '接入区域ID',
      `system_name` varchar(64) NOT NULL     COMMENT '接入系统名称',
      `system_code` varchar(64) NOT NULL     COMMENT '接入系统编码',
      `enabled` tinyint(2)    DEFAULT '0'  COMMENT '启用状态 (0.停止，1.启用)',
      `access_time` datetime      COMMENT '接入开通时间',
      `sort` int(4)    DEFAULT '0'  COMMENT '排序',
      `remark` varchar(128)      COMMENT '备注',
      `create_user_id` bigint(20)      COMMENT '创建用户',
      `create_time` datetime NOT NULL     COMMENT '创建时间',
      `update_time` datetime      COMMENT '更新时间',
      PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='区域接入系统';


-- ----------------------------
-- 排号汇总统计表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_ph_queue_stat`;
CREATE TABLE `mortals_xhx_ph_queue_stat` (
    `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'ID',
    `siteId` bigint(20)    DEFAULT '0'  COMMENT '站点Id',
    `siteCode` varchar(128)      COMMENT '站点编码',
    `siteName` varchar(128)      COMMENT '站点名称',
    `business` varchar(128) NOT NULL     COMMENT '业务名',
    `sectionName` varchar(128) NOT NULL     COMMENT '部门',
    `hallName` varchar(128) DEFAULT NULL COMMENT '大厅名称',
    `windowFromnum` varchar(128) NOT NULL     COMMENT '窗口编号',
    `waitTime` int(9) DEFAULT '0' COMMENT '平均等待时间,单位s',
    `phCount` int(9) NOT NULL COMMENT '取号数量',
    `year` int(9) NOT NULL COMMENT '年',
    `month` int(9) NOT NULL COMMENT '月',
    `day` int(9) NOT NULL COMMENT '日',
    `createTime` datetime NOT NULL COMMENT '创建时间',
    `updateUserId` bigint(20) DEFAULT NULL COMMENT '更新用户',
    `updateTime` datetime DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE
,KEY `year` (`year`) USING BTREE
,KEY `month` (`month`) USING BTREE
,KEY `day` (`day`) USING BTREE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='排队叫号汇总统计';


-- ----------------------------
-- 评价汇总表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_pj_evaluate_stat`;
CREATE TABLE `mortals_xhx_pj_evaluate_stat` (
`id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'ID',
`siteId` bigint(20)    DEFAULT '0'  COMMENT '站点Id',
`siteCode` varchar(128)      COMMENT '站点编码',
`siteName` varchar(128)      COMMENT '站点名称',
`sectionName` varchar(128) NOT NULL     COMMENT '部门',
`pjOption` varchar(32) NOT NULL     COMMENT '评价选项(非常满意,满意,基本满意,不满意,非常不满意)',
`windowFromnum` varchar(128) NOT NULL     COMMENT '窗口编号',
`hallName` varchar(128) DEFAULT NULL COMMENT '大厅名称',
`pjCount` int(9) NOT NULL COMMENT '评价数量',
`year` int(9) NOT NULL COMMENT '年',
`month` int(9) NOT NULL COMMENT '月',
`day` int(9) NOT NULL COMMENT '日',
`createTime` datetime NOT NULL COMMENT '创建时间',
`updateUserId` bigint(20) DEFAULT NULL COMMENT '更新用户',
`updateTime` datetime DEFAULT NULL COMMENT '更新时间',
PRIMARY KEY (`id`) USING BTREE
    ,KEY `year` (`year`) USING BTREE
    ,KEY `month` (`month`) USING BTREE
    ,KEY `day` (`day`) USING BTREE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='评价汇总统计';

-- ----------------------------
-- 汇总统计表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_stat`;
CREATE TABLE `mortals_xhx_stat` (
    `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'ID',
    `siteId` bigint(20)      COMMENT '站点Id',
    `siteCode` varchar(128)  DEFAULT ''     COMMENT '站点编码',
    `siteName` varchar(128)  DEFAULT ''    COMMENT '站点名称',
    `count` int(9) NOT NULL COMMENT '数量',
    `year` int(9) NOT NULL COMMENT '年',
    `month` int(9) NOT NULL COMMENT '月',
    `day` int(9) NOT NULL COMMENT '日',
    `createUserId` bigint(20)      COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateTime` datetime      COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE
    ,KEY `year` (`year`) USING BTREE
    ,KEY `month` (`month`) USING BTREE
    ,KEY `day` (`day`) USING BTREE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='汇总统计';




INSERT INTO `mortals_xhx_task` VALUES (null, '报表统计', 'SiteStatTask', 0, 'SiteStatTask', '', '', 1, 3600, '21:00', '', '192.168.1.107', '2024-05-18 16:05:00', 0, '2024-03-01 10:59:53', 1, '系统管理员');



-- ----------------------------
-- 区域统计日志表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_access_stat_log`;
CREATE TABLE mortals_xhx_access_stat_log(
   `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
   `access_id` bigint(20)    DEFAULT '0'   COMMENT '接入Id',
   `site_id` bigint(20)      COMMENT '站点Id',
   `site_code` varchar(128)    DEFAULT ''     COMMENT '站点编码',
   `site_name` varchar(128)   DEFAULT ''     COMMENT '站点名称',
   `stat_start_time` datetime      COMMENT '统计开始时间',
   `stat_end_time` datetime      COMMENT '统计结束时间',
   `duration` bigint(20) DEFAULT '0'     COMMENT '站点Id',
   `type` varchar(16) NOT NULL   DEFAULT '全部'  COMMENT '类型 (ALL.全部,PJQ.评价器,PDJ.排队机)',
   `remark` varchar(256)   DEFAULT ''     COMMENT '备注',
   `create_user_id` bigint(20)      COMMENT '创建用户',
   `create_time` datetime      COMMENT '创建时间',
   `update_time` datetime      COMMENT '更新时间',
   PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='统计日志表';




-- ----------------------------
-- 资源信息业务表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_resource`;
CREATE TABLE mortals_xhx_resource(
     `id` bigint(20)   AUTO_INCREMENT   COMMENT '菜单ID，主键，自增长',
     `name` varchar(50)      COMMENT '名称',
     `groupName` varchar(255)      COMMENT '分组名称',
     `url` varchar(2000)      COMMENT '连接地址，多个地址以逗号分隔',
     `authType` tinyint(2)    DEFAULT '3'  COMMENT '权限类型 (0.无限制，1.无需登录查看，2.需要登录查看，3.需要角色权限查看)',
     `sourceType` tinyint(2)    DEFAULT '0'  COMMENT '资源类型，(0.系统资源，1.开放资源)',
     `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
     `createUserName` varchar(50)      COMMENT '创建用户名称',
     `createTime` datetime NOT NULL     COMMENT '创建时间',
     `updateUserId` bigint(20)      COMMENT '更新用户',
     `updateUserName` varchar(50)      COMMENT '创建用户名称',
     `updateTime` datetime      COMMENT '更新时间',
     PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='资源信息业务';


-- ----------------------------
-- 角色信息业务表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_role`;
CREATE TABLE mortals_xhx_role(
     `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
     `name` varchar(50)      COMMENT '角色名称',
     `remark` varchar(200)      COMMENT '备注',
     `roleType` tinyint(2)    DEFAULT '2'  COMMENT '角色类型 (0.系统内置角色,1.默认系统角色.2.普通角色)',
     `customerId` bigint(20)      COMMENT '归属客户ID',
     `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
     `createUserName` varchar(50)      COMMENT '创建用户名称',
     `createTime` datetime NOT NULL     COMMENT '创建时间',
     `updateUserId` bigint(20)      COMMENT '更新用户',
     `updateUserName` varchar(50)      COMMENT '创建用户名称',
     `updateTime` datetime      COMMENT '更新时间',
     PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='角色信息业务';

-- ----------------------------
-- 角色资源权限业务表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_role_auth`;
CREATE TABLE mortals_xhx_role_auth(
  `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
  `roleId` bigint(20)      COMMENT '角色ID',
  `menuId` bigint(20)      COMMENT '菜单ID',
  `resourceId` bigint(20)      COMMENT '资源ID',
  `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
  `createUserName` varchar(50)      COMMENT '创建用户名称',
  `createTime` datetime NOT NULL     COMMENT '创建时间',
  `updateUserId` bigint(20)      COMMENT '更新用户',
  `updateUserName` varchar(50)      COMMENT '创建用户名称',
  `updateTime` datetime      COMMENT '更新时间',
  PRIMARY KEY  (`id`)
    ,KEY `createUserId` (`createUserId`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='角色资源权限业务';



-- ----------------------------
-- 角色用户业务表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_role_user`;
CREATE TABLE mortals_xhx_role_user(
  `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
  `roleId` bigint(20)      COMMENT '角色ID',
  `userId` bigint(20)      COMMENT '用户ID',
  `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
  `createUserName` varchar(50)      COMMENT '创建用户名称',
  `createTime` datetime NOT NULL     COMMENT '创建时间',
  `updateUserId` bigint(20)      COMMENT '更新用户',
  `updateUserName` varchar(50)      COMMENT '创建用户名称',
  `updateTime` datetime      COMMENT '更新时间',
  PRIMARY KEY  (`id`)
    ,KEY `createUserId` (`createUserId`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='角色用户业务';


-- ----------------------------
-- 菜单信息业务表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_menu`;
CREATE TABLE mortals_xhx_menu(
     `id` bigint(20)   AUTO_INCREMENT   COMMENT '菜单ID，主键，自增长',
     `name` varchar(50)      COMMENT '菜单名称',
     `url` varchar(256)      COMMENT '路由地址',
     `ancestors` varchar(255)      COMMENT '当前节点父id路径，“，”分割',
     `parentId` bigint(20)      COMMENT '父菜单ID，一级菜单的该字段值为-1',
     `linkType` tinyint(2)    DEFAULT '0'  COMMENT '链接方式 (0.普通，1.弹出，2.脚本)',
     `imgPath` varchar(128)      COMMENT '主菜单图标，主菜单图标的css样式名',
     `buttonImgPath` varchar(128)      COMMENT '按钮图标，按钮图标的css样式名',
     `imgCommPath` varchar(128)      COMMENT '常用菜单图标，常用菜单图标的css样式名',
     `commMenu` tinyint(2)    DEFAULT '1'  COMMENT '是否常用菜单 (0.非常用，1.常用)',
     `component` varchar(128)      COMMENT 'vue组件路径',
     `menuType` tinyint(2)    DEFAULT '0'  COMMENT '菜单类型 (0.目录，1.菜单，2.按钮)',
     `authType` tinyint(2)    DEFAULT '3'  COMMENT '权限类型 (0.无限制，1.无需登录查看，2.需要登录查看，3.需要角色权限查看)',
     `visible` tinyint(2)    DEFAULT '0'  COMMENT '菜单显示状态 (0.显示，1.隐藏)',
     `perms` varchar(512)      COMMENT '权限标识，多个逗号分割',
     `remark` varchar(512)      COMMENT '备注信息',
     `orderId` int(4)      COMMENT '排序编号',
     `status` tinyint(2)    DEFAULT '1'  COMMENT '菜单状态 (0.停用，1.启用)',
     `createTime` datetime      COMMENT '创建时间',
     `createUserId` bigint(20)      COMMENT '创建用户',
     `createUserName` varchar(50)      COMMENT '创建用户名称',
     `updateUserId` bigint(20)      COMMENT '更新用户',
     `updateUserName` varchar(50)      COMMENT '创建用户名称',
     `updateTime` datetime      COMMENT '更新时间',
     PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='菜单信息业务';


